@@ -811,12 +811,21 @@ False
 True
 
 '''      
-    if not (numpy_ma_isMA(a) or numpy_ma_isMA(b)):
+    a_is_masked = numpy_ma_isMA(a)
+    b_is_masked = numpy_ma_isMA(b)
+    
+    if not (a_is_masked or b_is_masked):
         try:
             return numpy_allclose(a, b, rtol=rtol, atol=atol)
         except (IndexError, NotImplementedError, TypeError):
             return numpy_all(a == b)
     else:
+        if a_is_masked and b_is_masked:
+            if (a.mask != b.mask).any():
+                return False
+        else:
+            return False
+
         try:
             return numpy_ma_allclose(a, b, rtol=rtol, atol=atol)
         except (IndexError, NotImplementedError, TypeError):
