@@ -3,6 +3,7 @@ from numpy import array as numpy_array
 from numpy import empty as numpy_empty
 from numpy import where as numpy_where
 from numpy import sum as numpy_sum
+from numpy import finfo as numpy_finfo
 from .data.data import Data
 from .coordinate import DimensionCoordinate
 from .functions import REGRID_LOGGING, FREE_MEMORY
@@ -377,9 +378,18 @@ of the grid.
             raise ValueError('Cartesian grid must have between 1 and 3 ' +
                              'dimensions.')
         #--- End: if
+        
+        # For 1D conservative regridding add an extra dimension of size 1
         if ndim == 1:
+            if not use_bounds:
+                # For 1D nonconservative  regridding the extra dimension should
+                # already have been added in cf.Field.regridc.
+                raise ValueError('Cannot create a Cartesian grid from one ' +
+                                 'dimension coordinate with no bounds.')
             coords = [DimensionCoordinate(data=Data(0),
-                                          bounds=Data([-1e-6,1e-6]))] + coords
+                                          bounds=Data([numpy_finfo('float32').epsneg,
+                                                       numpy_finfo('float32').eps]))] \
+                     + coords
             if mask is not None:
                 mask = mask[None,:]
             ndim = 2
@@ -505,7 +515,11 @@ returned.
 
         """
         if len(data_list) > 1:
-            return Data.concatenate(data_list, axis=axis)
+#            return Data.concatenate(data_list, axis=axis)
+            data = Data.concatenate(data_list, axis=axis)
+#?            if data.fits_in_one_chunk_in_memory(data.dtype.itemsize):
+#?                data.varray
+            return data            
         else:
             assert len(data_list) == 1
             return data_list[0]
@@ -664,6 +678,11 @@ coordinates are searched for and if found returned.
             f_2D = True
         else:
             f_2D = False
+            # Check for size 1 latitude or longitude dimensions
+            if x_size == 1 or y_size == 1:
+                raise ValueError('Neither the longitude nor latitude dimension' +
+                                 ' coordinates of the ' + name + ' field can' +
+                                 ' be of size 1.')
         #--- End: if
         
         return x, y, x_axis, y_axis, x_key, y_key, x_size, y_size, f_2D
