@@ -6,7 +6,7 @@ def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
           fletcher32=False, no_shuffle=False, datatype=None,
           single=False, double=False, reference_datetime=None,
           variable_attributes=None, HDF_chunksizes=None,
-          unlimited=None):
+          unlimited=None, _debug=False):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
     
 NetCDF dimension and variable names will be taken from variables'
@@ -280,5 +280,6 @@ and auxiliary coordinate roles for different data variables.
                      datatype=datatype, single=single, double=double,
                      reference_datetime=reference_datetime,
                      variable_attributes=variable_attributes,
-                     HDF_chunks=HDF_chunksizes, unlimited=unlimited)
+                     HDF_chunks=HDF_chunksizes, unlimited=unlimited,
+                     _debug=_debug)
 #--- End: def
