@@ -50,22 +50,25 @@ class RegridTest(unittest.TestCase):
             f1 = cf.read(self.filename1)
             f2 = cf.read(self.filename2)
             f3 = cf.read(self.filename3)
-            self.assertTrue(f3.equals(f1.regrids(f2), traceback=True),
+            self.assertTrue(f3.equals(f1.regrids(f2, axis_order='ZT'), traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
-            self.assertTrue(f3.equals(f1.regrids(f2, method='conservative'), traceback=True),
+            self.assertTrue(f3.equals(f1.regrids(f2, axis_order='ZT', method='conservative'),
+                                      traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
             dst = {'longitude': f2.dim('X'), 'latitude': f2.dim('Y')}
-            self.assertTrue(f3.equals(f1.regrids(dst, dst_cyclic=True),
+            self.assertTrue(f3.equals(f1.regrids(dst, dst_cyclic=True, axis_order='ZT'),
                                       traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
             self.assertTrue(f3.equals(f1.regrids(dst, method='conservative',
-                                                 dst_cyclic=True), traceback=True),
+                                                 dst_cyclic=True, axis_order='ZT'),
+                                      traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
             f4 = cf.read(self.filename4)
             f5 = cf.read(self.filename5)
-            self.assertTrue(f4.equals(f1.regrids(f5), traceback=True),
+            self.assertTrue(f4.equals(f1.regrids(f5, axis_order='ZT'), traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
-            self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear'), traceback=True),
+            self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear', axis_order='ZT'),
+                                      traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
